@@ -1,6 +1,6 @@
 from enum import Enum
 
 
-class PollType(Enum):
+class PollType(int, Enum):
     SINGLE_CHOOSE = 0
     MULTIPLE_CHOOSE = 1
